Re-exports
pub use data_source::ConfigData;pub use data_source::ExperimentData;pub use data_source::SuperpositionDataSource;pub use local_provider::LocalResolutionProvider;pub use remote_provider::SuperpositionAPIProvider;pub use client::*;pub use provider::*;pub use traits::*;pub use types::*;
Modules
Structs
- Evaluation
Context - The evaluation context provides ambient information for the purposes of flag evaluation. Contextual data may be used as the basis for targeting, including rule-based evaluation, overrides for specific subjects, or fractional flag evaluation.
- Provider
Metadata - The metadata of a feature provider.
- Resolution
Details - A structure which contains a subset of the fields defined in the evaluation details, representing the result of the provider’s flag resolution process.
Enums
- Provider
Status - The status of a feature provider.